host_pinned

Function host_pinned 

pub fn host_pinned(config_dir: &Path, dest_token: &str) -> bool
True if dest_token already has a pinned host key in our known_hosts (the bootstrap already ran for it at least once).